#
# spec file for package cargo-c
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019 Andreas Schneider <asn@cryptomilk.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags -Clink-arg=-Wl,-z,relro,-z,now -C debuginfo=2

Name:           cargo-c
Version:        0.9.27~git0.54774e0
Release:        1.1
Summary:        Helper to build and install c-like libraries from Rust
License:        MIT
Group:          Development/Languages/Rust

URL:            https://crates.io/crates/cargo-c
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config

Source1000:     README.suse-maint
BuildRequires:  cargo
BuildRequires:  pkgconfig(openssl)

%description
The is a cargo applet to build and install C-ABI compatibile dynamic and static
libraries from Rust.

It produces and installs a correct pkg-config file, a static library and a
dynamic library, and a C header to be used by any C (and C-compatible)
software.

%prep
%autosetup -a1 -p1

install -d -m 0755 .cargo
cp %{SOURCE2} .cargo/config

%build
export RUSTFLAGS="%{rustflags}"
cargo build --offline --release

%install
export RUSTFLAGS="%{rustflags}"
cargo install --offline --root=%{buildroot}%{_prefix} --path .

find %{buildroot} -name .crates2.json -delete
rm -rf %{buildroot}%{_datadir}/cargo/registry
rm %{buildroot}%{_prefix}/.crates.toml

%files
%license LICENSE
%doc README.md
%{_bindir}/cargo-capi
%{_bindir}/cargo-cbuild
%{_bindir}/cargo-cinstall
%{_bindir}/cargo-ctest

%changelog
* Tue Oct 17 2023 bjorn.lie@gmail.com
- Update to version 0.9.27~git0.54774e0:
  * Complete the soversion granularity
  * Bump cbindgen
  * Make sure the version variables are consistent
  * Fix sover detection for 0-based versioning
  * Bump cargo version
  * Bump cbindgen
  * Do not pass the token to clippy-check
- Switch _service to manual.
* Tue Mar 14 2023 Dirk Müller <dmueller@suse.com>
- add constraints to avoid out of disk space errors
* Mon Jan  2 2023 asn@cryptomilk.org
- Update to version 0.9.15~git0.2d3044b:
  * Prepare for release
  * Update to cargo-0.67 and clap-4
  * macos: Allow larger install_name entries
  * Fix the new clippy lints
  * Don't include version in soname ELF header if versioning is disabled
  * Use get_many instead of values_of_lossy
  * Use macos-12 for the macos runner
  * Add job deps
  * Generate paths relative to ${prefix} in the pkg-config file even if --libdir or --includedir are given
  * Compact the main CI
  * Fix more warnings in the main CI
  * Use a custom release profile to strip binaries
  * ci(deploy): Use musl abi for aarch64 linux binary, add i686 linux
  * Remove msys2 test
  * Update the example-project CI
  * Make sure the supported rustc version is evident
  * Use the default compiler to build a static binary for musl
  * Save all the linux binaries
  * Prepare for release
  * Add pre-built ppc64le and aarch64 linux binaries
  * Simplify the deploy script
  * Fix new clippy lints
  * Update to cargo-0.66
  * Use dtolnay/rust-toolchain
  * Remove actions-rs/cargo
  * Prepare for release
  * add support for illumos
  * Bump cargo version
  * Prepare for release
  * Bump cargo to 0.64
  * Install the windows DLL in the libdir if it is custom
  * Fix typo on readme
  * Bump the codecov action
  * Add sonames on musl
* Mon Jul  4 2022 asn@cryptomilk.org
- Update to version 0.9.11~git0.41f5562:
  * Prepare for release
  * Fix clippy warnings
  * Versions bump
  * Add back the deps.rs badge
  * Increase the regex requirement
  * Prepare for release
  * Bump cargo
  * Add support for Haiku Operating System
  * Add udbserver to users
  * Extend the coverage further
  * Fix the code coverage script
  * Fix subcommand fallback support
  * Print the issued commands
  * Fix testing cross compilation
  * Bump cargo-metadata
  * Bump cbindgen
  * Support rustc-1.60 and following
  * Update to clap-3.1 and cargo-0.61
  * Prepare for release
  * Do not use the patch version in macOS -install_name
  * Add Android to the build targets supported by LibType
  * Make nightly clippy happy
  * Simplify a writln
  * Prepare for release
  * Bump cargo version
  * Remove newlines from the description
  * Make the default destdir None
  * CI: use MSYS2 cargo package for example project
  * Print the PKG_CONFIG_PATH in verbose mode
* Wed Mar  2 2022 William Brown <william.brown@suse.com>
- Update vendored libraries to resolve security issues.
* Mon Jan 10 2022 asn@cryptomilk.org
- Update to version 0.9.6~git0.68e65ad:
  * Prepare for release
  * Bump cargo
  * Support custom paths for data files as it is available for includes
  * Fix the datadir description
  * Change the configuration paths for datadir
  * Add datadir destination path customization
  * Suppress warning about dead code for Common
  * Add datadir support
  * Make sure the right rust is used on deploy
  * Bump the edition in the examples
* Thu Jan  6 2022 william.brown@suse.com
- resolve bsc#1194113 (CVE-2018-25023)
- resolve bsc#1194119 (CVE-2021-45710)
* Wed Jun  2 2021 william.brown@suse.com
- Update to version 0.8.1~git0.cce1b08:
  * Prepare for release
  * Set the capi.library.rustflags
  * Add a simple way to set the RUSTFLAGS from Cargo.toml
  * CI: test example project in Windows/MSYS2 (#191)
  * Update cargo requirement from 0.52 to 0.53
  * Upgrade to GitHub-native Dependabot
  * Default to nightly
  * Use codecov
  * Move the code coverage in a stand-alone script
  * Enable colored help
* Tue Apr  6 2021 William Brown <william.brown@suse.com>
- Add README.suse-maint to fix OBS warning.
* Mon Apr  5 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.8.0
  * cbindgen 0.18
  * provide a cli option to have fully static builds.
  * cargo cinstall and cargo capi install now imply --release
    to match the behavior of cargo install.
* Wed Jan 13 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.7.0
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.7.0
* Sun Oct 18 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.15
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.15
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.14
- Removed 123.patch
* Tue Oct 13 2020 Andreas Schneider <asn@cryptomilk.org>
- Added 123.patch
  * Save the include subdir to a specific field
* Wed Sep  9 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.13
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.13
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.12
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.11
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.10
* Mon Jul 13 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.9
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.9
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.8
* Mon Jun  8 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.7
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.7
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.6
* Tue Jun  2 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.5
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.5
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.4
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.3
* Thu Apr  2 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.2
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.2
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.1
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.6.0
* Sun Dec 15 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.5.0
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.5.0
  * https://github.com/lu-zero/cargo-c/releases/tag/v0.4.0
* Mon Dec  9 2019 Andreas Schneider <asn@cryptomilk.org>
- Set rust compiler and rust flags
* Wed Nov 20 2019 Andreas Schneider <asn@cryptomilk.org>
- Initial package version 0.3.1
